
% time series %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
N=96;
deltat=2.5; %sec
t=((1:N)'-1)*deltat;

A1=10; A2=1; A3=3; A4=1;
nu1=0/(deltat*N); nu2=4/(deltat*N); nu3=8/(deltat*N); nu4=32/(deltat*N);
y1=zeros(N,1); y2=zeros(N,1); y3=zeros(N,1); y4=zeros(N,1); 
for j=1:N
    y1(j,1)=A1*cos(2*pi*nu1*(j-1)*deltat);
    y2(j,1)=A2*cos(2*pi*nu2*(j-1)*deltat);
    y3(j,1)=A3*sin(2*pi*nu3*(j-1)*deltat);
    y4(j,1)=A4*sin(2*pi*nu4*(j-1)*deltat);
end
y=y1+y2+y3+y4;

figure;
plot(t,y1,'k','LineWidth',1.5)
xlim([0,deltat*N]), ylim([9,11])
set(gca,'xtick',(0:deltat*N/8:deltat*N),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(9:.2:11),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','TimeSeries1')
figure;
plot(t,y2,'k','LineWidth',1.5)
xlim([0,deltat*N]), ylim([-1,1])
set(gca,'xtick',(0:deltat*N/8:deltat*N),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(-1:.2:1),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','TimeSeries2')
figure;
plot(t,y3,'k','LineWidth',1.5)
xlim([0,deltat*N]), ylim([-3,3])
set(gca,'xtick',(0:deltat*N/8:deltat*N),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(-3:1:3),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','TimeSeries3')
figure;
plot(t,y4,'k','LineWidth',1.5)
xlim([0,deltat*N]), ylim([-1,1])
set(gca,'xtick',(0:deltat*N/8:deltat*N),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(-1:.2:1),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','TimeSeries4')
figure;
plot(t,y,'k','LineWidth',1.5)
xlim([0,deltat*N]), ylim([5,15])
set(gca,'xtick',(0:deltat*N/8:deltat*N),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(5:2:15),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','TimeSeries')

figure;
imagesc(repmat(real(y1),[1,N/16]),[9,11])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgR')
figure;
imagesc(repmat(abs(imag(y1)),[1,N/16]),[0,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgI')
figure;
imagesc(repmat(real(y2),[1,N/16]),[-1,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgR')
figure;
imagesc(repmat(abs(imag(y2)),[1,N/16]),[0,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgI')
figure;
imagesc(repmat(real(y3),[1,N/16]),[-3,3])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgR')
figure;
imagesc(repmat(abs(imag(y3)),[1,N/16]),[0,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgI')
figure;
imagesc(repmat(real(y4),[1,N/16]),[-1,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgR')
figure;
imagesc(repmat(abs(imag(y4)),[1,N/16]),[0,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgI')

figure;
imagesc(repmat(real(y),[1,N/16]),[5,15])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgR')
figure;
imagesc(repmat(abs(imag(y)),[1,N/16]),[0,1])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','TimeSeriesImgI')

% frequency spectrum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
deltanu=1/(N*deltat);
nu=((1:N)'-N/2-1)*deltanu;

% DFT by matrix mult
OmegaBarC=zeros(N,N);
for k=1:N         
   for j=1:N
      OmegaBarC(k,j)=exp(-1i*2*pi*(k-1)*(j-1)/N);
   end
end

figure;
imagesc(real(OmegaBarC),[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBarR')
figure;
imagesc(imag(OmegaBarC),[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBarI')

% DFT by complex multiplication, Shift so zero freq in middle
FOmegaBar =fftshift(OmegaBarC*y ); 
FOmegaBar1=fftshift(OmegaBarC*y1); 
FOmegaBar2=fftshift(OmegaBarC*y2); 
FOmegaBar3=fftshift(OmegaBarC*y3);
FOmegaBar4=fftshift(OmegaBarC*y4); 

figure;
plot(nu,real(FOmegaBar),'k','LineWidth',1.5)
xlim([-1/deltat/2,1/deltat/2]),ylim([0,N])%y height is 2*A1*N/2
set(gca,'xtick',round(nu(1:N/8:N),2),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(0:N/4:N),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','FreqSpectrumR')
figure;
plot(nu,imag(FOmegaBar),'k','LineWidth',1.5)
xlim([-1/deltat/2,1/deltat/2]),ylim([-A3*N/2,A3*N/2])
set(gca,'xtick',round(nu(1:N/8:N),2),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(-A3*N/2:N/2:A3*N/2),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','FreqSpectrumI')
figure;
plot(nu,abs(FOmegaBar),'k','LineWidth',1.5)
xlim([-1/deltat/2,1/deltat/2]),ylim([0,N])%y height is 2*A1*N/2
set(gca,'xtick',round(nu(1:N/8:N),2),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',(-N:N/4:N),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','FreqSpectrumM')
figure;
plot(nu,angle(FOmegaBar),'k','LineWidth',1.5)
xlim([-1/deltat/2,1/deltat/2]),ylim([-pi,pi])
set(gca,'xtick',round(nu(1:N/8:N),2),'FontSize',12,'FontWeight','bold')
set(gca,'ytick',round((-pi:pi/2:pi),2),'FontSize',12,'FontWeight','bold')
%print(gcf,'-dtiffn','-r300','FreqSpectrumP')

figure;
imagesc(repmat(real(FOmegaBar),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgR')
figure;
imagesc(repmat(abs(imag(FOmegaBar)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgI')
figure;
imagesc(repmat(abs(FOmegaBar),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgM')
figure;
imagesc(repmat(angle(FOmegaBar),[1,N/16]),[-pi,pi])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgP')

figure;
imagesc(repmat(real(FOmegaBar1),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg1R')
figure;
imagesc(repmat(abs(imag(FOmegaBar1)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg1I')
figure;
imagesc(repmat(real(FOmegaBar2),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg2R')
figure;
imagesc(repmat(abs(imag(FOmegaBar2)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg2I')
figure;
imagesc(repmat(real(FOmegaBar3),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg3R')
figure;
imagesc(repmat(abs(imag(FOmegaBar3)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg3I')
figure;
imagesc(repmat(real(FOmegaBar4),[1,N/16]),[0,N]) %A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg4R')
figure;
imagesc(repmat(abs(imag(FOmegaBar4)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg4I')

% IDFT by matrix mult
OmegaC=zeros(N,N);
for k=1:N         
   for j=1:N
      OmegaC(k,j)=exp(1i*2*pi*(k-(N/2+1))*(j-(N/2+1))/N);
   end
end
OmegaC=OmegaC/N;

figure;
imagesc(real(OmegaC),[-1/N,1/N]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaR')
figure;
imagesc(imag(OmegaC),[-1/N,1/N]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaI')

% FT by matrix/ vector representation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
yR=real(y); yI=imag(y);
OmegaBar=[real(OmegaBarC),-imag(OmegaBarC);imag(OmegaBarC),real(OmegaBarC)];

fvec=OmegaBar*[yR;yI];
fR=fvec(1:N,1); fI=fvec(N+1:2*N,1);

ff=fftshift(fR+sqrt(-1)*fI); % shift so zero freq in center
f=[real(ff);imag(ff)];

figure;
imagesc(repmat(real(ff),[1,N/16]),[0,N])%A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgR2')
figure;
imagesc(repmat(abs(imag(ff)),[1,N/16]),[0,A3*N/2])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgI2')
figure;
imagesc(repmat(abs(ff),[1,N/16]),[0,N])%A1*N
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgM2')
figure;
imagesc(repmat(angle(ff),[1,N/16]),[-pi,pi])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgP2')










