close all
clear all

% define parameters
Ny=96; Nx=Ny;

FOVy=240; FOVx=240; deltay=FOVy/Ny; deltax=FOVx/Nx;
deltakx=1/Ny/deltax; deltaky=1/Nx/deltay;

A1=10; A2=1.5; A3=1; A4=3;
nu1=0/240; nu2=8/240; nu3=24/240; nu4=16/240;

% make image data
Y1=zeros(Ny,Nx); Y2=zeros(Ny,Nx); Y3=zeros(Ny,Nx); Y4=zeros(Ny,Nx);
for k=1:Ny
    for j=1:Nx
        Y1(k,j)= A1*cos(2*pi*nu1*(j-1)*deltax);
        Y2(k,j)= A2*cos(2*pi*nu2*(j-1)*deltax);
        Y3(k,j)= A3*sin(2*pi*nu3*(k-1)*deltay);
        Y4(k,j)= A4*cos(2*pi*nu4*(j-1)*deltax+2*pi*nu4*(k-1)*deltay);    
    end
end
Y=Y1+Y2+Y3+Y4;

figure;
imagesc(Y1,[-15,15])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','Image1')
figure;
imagesc(Y2,[-1.5,1.5])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','Image2')
figure;
imagesc(Y3,[-1,1])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','Image3')
figure;
imagesc(Y4,[-3,3])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','Image4')
figure;
imagesc(Y,[-15,15])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','Image')

%  take Fourier transform
OmegaBarxC=zeros(Nx,Nx);
for k=1:Nx        
    for j=1:Nx
      OmegaBarxC(k,j)=exp(-1i*2*pi*(k-1)*(j-1)/Nx);
   end
end
OmegaBaryC=zeros(Ny,Ny);
for k=1:Ny        
    for j=1:Ny
      OmegaBaryC(k,j)=exp(-1i*2*pi*(k-1)*(j-1)/Ny);
   end
end

figure;
imagesc(real(OmegaBaryC),[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBaryR')
figure;
imagesc(imag(OmegaBaryC),[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBaryI')
figure;
imagesc(real(OmegaBarxC)',[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBarxRt')
figure;
imagesc(imag(OmegaBarxC)',[-1,1]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaBarxIt')

F  = fftshift(OmegaBaryC*Y *transpose(OmegaBarxC));
F1 = fftshift(OmegaBaryC*Y1*transpose(OmegaBarxC));
F2 = fftshift(OmegaBaryC*Y2*transpose(OmegaBarxC));
F3 = fftshift(OmegaBaryC*Y3*transpose(OmegaBarxC));
F4 = fftshift(OmegaBaryC*Y4*transpose(OmegaBarxC));

% get rid of all the values that are zero within machine precision
F1=round(F1,1); F2=round(F2,1); F3=round(F3,1); F4=round(F4,1); F=round(F,1); 

figure;
imagesc(real(F),[0,2*Nx*Ny/2])%A1*2*Nx*Ny/2  
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgR')
figure;
imagesc(abs(imag(F)),[0,Nx*Ny/2])%A3*Nx*Ny/2  
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgI')
figure;
imagesc(abs(F),[0,2*Nx*Ny/2])%A1*2*Nx*Ny/2  
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgM')
figure;
imagesc(angle(F),[-pi,pi]) 
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImgP')

figure;
imagesc(real(F1),[0,2*Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg1R')
figure;
imagesc(abs(imag(F1)),[0,2*Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg1I')
figure;
imagesc(real(F2),[0,2*Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg2R')
figure;
imagesc(abs(imag(F2)),[0,1])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg2I')
figure;
imagesc(real(F3),[0,1])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg3R')
figure;
imagesc(abs(imag(F3)),[0,Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg3I')
figure;
imagesc(real(F4),[0,2*Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg4R')
figure;
imagesc(abs(imag(F4)),[0,2*Nx*Ny/2])
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FreqSpectrumImg4I')


% take inverse Fourier transforms
OmegaxC=zeros(Nx,Nx);
for k=1:Nx
    for j=1:Nx
        OmegaxC(k,j)=exp(1i*2*pi*(k-(Nx/2+1))*(j-(Nx/2+1))/Nx);
    end
end
OmegaxC=OmegaxC/Nx;
OmegayC=zeros(Ny,Ny);
for k=1:Ny
    for j=1:Ny
        OmegayC(k,j)=exp(1i*2*pi*(k-(Ny/2+1))*(j-(Ny/2+1))/Ny);
    end
end
OmegayC=OmegayC/Ny;

figure;
imagesc(real(OmegaxC),[-1/Nx,1/Nx]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegayR')
figure;
imagesc(imag(OmegaxC),[-1/Nx,1/Nx]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegayI')
figure;
imagesc(real(OmegayC)',[-1/Ny,1/Ny]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaxRt')
figure;
imagesc(imag(OmegayC)',[-1/Ny,1/Ny]);
axis image,colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','OmegaxIt')

YY1 = (OmegayC*F1*transpose(OmegaxC));
YY2 = (OmegayC*F2*transpose(OmegaxC));
YY3 = (OmegayC*F3*transpose(OmegaxC));
YY4 = (OmegayC*F4*transpose(OmegaxC));
YY  = (OmegayC*F *transpose(OmegaxC));

figure;
imagesc(real(YY1),[0,15]) 
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image1Rr')
% figure;
% imagesc(imag(YY1),[0,15]) 
% axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image1Ir')
figure;
imagesc(real(YY2),[-1.5,1.5])
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image2Rr')
% figure;
% imagesc(imag(YY2),[-3,3])
% axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image2Ir')
figure;
imagesc(real(YY3),[-1,1])
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image3Rr')
figure;
imagesc(imag(YY3),[-1,1])
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image3Ir')
figure;
imagesc(real(YY4),[-3,3])
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','Image2Ir')
% figure;
% imagesc(imag(YY4),[-3,3])
% axis image, colormap(gray), axis off

figure;
imagesc(real(YY),[-15,15])
axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','ImageRr')
% figure;
% imagesc(imag(YY),[-15,15])
% axis image, colormap(gray), axis off
% %print(gcf,'-dtiffn','-r300','ImageIr')

figure;
imagesc(real(YY)-real(Y),[-1,1])
axis image, colormap(gray), axis off




