% data from P44032.7 slice 5 (Muge's data different slice)
% Performs n/2 Nyquist Ghost correction 

clear all 
close all

load Fng
load Fne

% get dimensions
[Ny,Nx]=size(Fng);
Nnavs=size(Fne,1);

% Before Correction k-space
figure;
imagesc(real(Fng))
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FngR')
figure;
imagesc(imag(Fng)) 
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FngI')
figure;
imagesc(abs(Fng))
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FngM')
figure;
imagesc(angle(Fng),[-pi,pi]) 
axis image, axis off, colormap(gray)
%print(gcf,'-dtiffn','-r300','FngP')

% Take inverse Fourier transforms
% Yng=fftshift(ifft2(fftshift(Fng)));
OmegaxC=zeros(Nx,Nx);
for k=1:Nx
    for j=1:Nx
        OmegaxC(k,j)=exp(1i*2*pi*(k-(Nx/2+1))*(j-(Nx/2+1))/Nx);
    end
end
OmegaxC=OmegaxC/Nx;
OmegayC=zeros(Ny,Ny);
for k=1:Ny
    for j=1:Ny
        OmegayC(k,j)=exp(1i*2*pi*(k-(Ny/2+1))*(j-(Ny/2+1))/Ny);
    end
end
OmegayC=OmegayC/Ny;

% Before Correction Image
Yng = (OmegayC*Fng*transpose(OmegaxC));

figure;
imagesc(real(Yng),[-7.5,7.5])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','ImageRng')
figure;
imagesc(imag(Yng),[-7.5,7.5])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','ImageIng')
figure;
imagesc(abs(Yng),[0,7.5])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','ImageMng')
figure;
imagesc(angle(Yng),[-pi,pi])
axis image, colormap(gray), axis off
%print(gcf,'-dtiffn','-r300','ImagePng')



%Do Nyquist correcction % 

% Fourier transform each row of kspace and navigators
%navs = fftshift(fft(fftshift(Fne,2),[],2),2);
OmegaBarC=zeros(Nx,Nx);
for k=1:Nx    
   for j=1:Nx
      OmegaBarC(k,j)=exp(-1i*2*pi*(k-(Nx/2+1))*(j-(Nx/2+1))/Nx);
   end
end
navs=zeros(3,Nx);
for j=1:3
    navs(j,:)=transpose(OmegaBarC*transpose(Fne(j,:)));
end
nav1 = navs(1,:); nav2 = navs(2,:); nav3 = navs(3,:);
%data = fftshift(fft(fftshift(Fng,2),[],2),2);
data=zeros(Ny,Nx);
for j=1:Ny
    data(j,:)=transpose(OmegaBarC*transpose(Fng(j,:)));
end

%Find the phase shift from the navigators in freq space
% center frequency offset w0
w0 = angle(nav3./nav1);
delPhase = (nav2.*exp(-0.5i.*w0)./nav1);
% median this way works better than angle(mean(delPhase)) or angle(median(delPhase))
delPhase = angle(median(real(delPhase),2)+sqrt(-1)*median(imag(delPhase),2));
save delPhase delPhase

%  Subtract the phase shift in freq space
data(1:2:end,:) = data(1:2:end,:).*repmat(exp(-1i.*(delPhase+pi)),[size(data,1)/2,size(data,2)]);

% Inverse Fourier transform the Nyquist ghost corrected (phase) shifted rows
% F = fftshift(ifft(fftshift(data,2),[],2),2);
Omega2C=zeros(Nx,Nx);
for k=1:Nx    
   for j=1:Nx
      Omega2C(k,j)=exp(1i*2*pi*(k-(Nx/2+1))*(j-(Nx/2+1))/Nx);
   end
end
Omega2C=Omega2C/Nx;
F=zeros(Ny,Nx);
for j=1:Ny
    F(j,:)=transpose(Omega2C*transpose(data(j,:)));
end

% After Correction Image
%Y2=fftshift(ifft2(fftshift(F)));
Y2 = (OmegayC*F*transpose(OmegaxC));
figure;
subplot(1,2,1)
imagesc(abs(Y2),[0,7.5])
axis image, colormap(gray), axis off
subplot(1,2,2)
imagesc(angle(Y2),[-pi,pi])
axis image, colormap(gray), axis off

save F F









