
clear all
close all

% parameters
Ny=8; Nx=Ny;% x-dimension of k-space array

FOVy=240; FOVx=240; deltay=FOVy/Ny; deltax=FOVx/Nx;
deltakx=1/Ny/deltax; deltaky=1/Nx/deltay;

% Generate image to be FT'd for isomorphism reconstruction
mag=10^(-6)*ones(Ny,Nx); pha = pi/6;
mag(3:6,3:6)=.5; mag(4,[3,6])=1;  mag(6,[4,5])=1;

YY=mag*cos(pha)+sqrt(-1)*mag*sin(pha);

figure;
imagesc(real(YY), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageR')
figure;
imagesc(imag(YY), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageI')
figure;
imagesc(abs(YY), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageM')
figure;
imagesc(angle(YY), [-pi pi])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageP')

% Generate k-space from image
OmegaBarxC=zeros(Nx,Nx);
for k=1:Nx
    for j=1:Nx
        OmegaBarxC(k,j)=exp(-1i*2*pi*(k-1)*(j-1)/Nx);
    end
end
OmegaBaryC=OmegaBarxC; % same dimensions

figure;
imagesc(real(OmegaBaryC),[-1,1]);
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','OmegaBaryR')
figure;
imagesc(imag(OmegaBaryC),[-1,1]);
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','OmegaBaryI')
figure;
imagesc(real(OmegaBarxC)',[-1,1]);
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','OmegaBarxRt')
figure;
imagesc(imag(OmegaBarxC)',[-1,1]);
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','OmegaBarxIt')

F = fftshift(OmegaBaryC*fftshift(YY)*transpose(OmegaBarxC));

clear OmegaBaryC OmegaBarxC

figure;
imagesc(real(F))
axis image, axis off, colormap(gray)
print(gcf,'-dtiffn','-r300','FreqImgR')
figure;
imagesc(imag(F))
axis image, axis off, colormap(gray)
print(gcf,'-dtiffn','-r300','FreqImgI')
figure;
imagesc(abs(F))
axis image, axis off, colormap(gray)
print(gcf,'-dtiffn','-r300','FreqImgM')
figure;
imagesc(angle(F),[-pi,pi])
axis image, axis off, colormap(gray)
print(gcf,'-dtiffn','-r300','FreqImgP')

f=[reshape(real(F)',Nx*Ny,1);reshape(imag(F)',Nx*Ny,1)];

figure;
imagesc(repmat(f,[1,16]));
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','kspacevec')


% IFT reconstruction matrix Matrix
OmegaxC=zeros(Nx,Nx);
for k=1:Nx
    for j=1:Nx
        OmegaxC(k,j)=exp(1i*2*pi*(k-(Nx/2+1))*(j-(Nx/2+1))/Nx);
    end
end
OmegaxC=OmegaxC/Nx;
OmegayC=OmegaxC;

OmegaxR=real(OmegaxC); OmegaxI=imag(OmegaxC);
OmegayR=real(OmegayC); OmegayI=imag(OmegayC);
clear OmegayC OmegaxC    

OmegaR=kron(OmegayR,OmegaxR)-kron(OmegayI,OmegaxI);
OmegaI=kron(OmegayR,OmegaxI)+kron(OmegayI,OmegaxR);

Omega=[OmegaR,-OmegaI;OmegaI,OmegaR];
y=Omega*f;

figure;
imagesc(Omega)
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','Omega')

figure;
imagesc(repmat(y,[1,16]),[-1,1]);
axis image,colormap(gray), axis off
print(gcf,'-dtiffn','-r300','imagevec')

Y=complex(reshape(y(1:Ny*Nx,1),Ny,Nx)',reshape(y(Ny*Nx+1:2*Ny*Nx,1),Ny,Nx)');

figure;
imagesc(real(Y), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageR')
figure;
imagesc(imag(Y), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageI')
figure;
imagesc(abs(Y), [-1 1])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageM')
figure;
imagesc(angle(Y), [-pi pi])
axis image; colormap gray; axis off
print(gcf,'-dtiffn','-r300','ImageP')




