% If NKx=6 make image then k-space (for zfill to 8)
% If NKx=8 make image then k-space
% If NKx~=6 or ~=8 or ~=96 read 96 k-space and truncate (for zfill to 96)
% If NKx=96 read 96x96 k-space

function [F] = getF(NKy,showims)

NKx=NKy;
% Initial k-space array %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (NKy==6)||(NKy==8) % make image then its k-space
    % Generate image to be FT'd for isomorphism reconstruction
    mag=10^(-6)*ones(NKy,NKx); pha = pi/6;
    if     (NKy==6)
        mag(2:5,2:5)=.5; mag(3,[2,5])=1; mag(5,(3:4))=1;
    elseif (NKy==8)
        mag(3:6,3:6)=.5; mag(4,[3,6])=1;  mag(6,[4,5])=1;
    end
    YY=mag*cos(pha)+sqrt(-1)*mag*sin(pha);
    if (showims==1)
        figure;
        imagesc(real(YY), [-1 1])
        axis image; colormap gray; axis off
        print(gcf,'-dtiffn','-r300','ImageR')
        figure;
        imagesc(imag(YY), [-pi pi])
        axis image; colormap gray; axis off
        print(gcf,'-dtiffn','-r300','ImageI')
        figure;
        imagesc(abs(YY), [-1 1])
        axis image; colormap gray; axis off
        print(gcf,'-dtiffn','-r300','ImageM')
        figure;
        imagesc(angle(YY), [-pi pi])
        axis image; colormap gray; axis off
        print(gcf,'-dtiffn','-r300','ImageP')
    end
    % Generate k-space from image
    OmegaBarxC=zeros(NKx,NKx);
    for k=1:NKx
        for j=1:NKx
            OmegaBarxC(k,j)=exp(-1i*2*pi*(k-1)*(j-1)/NKx);
        end
    end
    OmegaBaryC=OmegaBarxC; % same dimensions
    if (showims==1)
        figure;
        imagesc(real(OmegaBaryC),[-1,1]);
        axis image,colormap(gray), axis off
        print(gcf,'-dtiffn','-r300','OmegaBaryR')
        figure;
        imagesc(imag(OmegaBaryC),[-1,1]);
        axis image,colormap(gray), axis off
        print(gcf,'-dtiffn','-r300','OmegaBaryI')
        figure;
        imagesc(real(OmegaBarxC)',[-1,1]);
        axis image,colormap(gray), axis off
        print(gcf,'-dtiffn','-r300','OmegaBarxRt')
        figure;
        imagesc(imag(OmegaBarxC)',[-1,1]);
        axis image,colormap(gray), axis off
        print(gcf,'-dtiffn','-r300','OmegaBarxIt')
    end
    F = fftshift(OmegaBaryC*fftshift(YY)*transpose(OmegaBarxC));
    clear OmegaBaryC OmegaBarxC
else % load k-space array for processing and ift
    cd .., cd .., cd Section3, cd code3_2
    load F
    cd .., cd ..,cd Section4, cd code4_2
    if (NKy~=96)
        % truncate k-space from 96 to NKy
        F=F(96/2-NKy/2:96/2+NKy/2-1,96/2-NKy/2:96/2+NKy/2-1);
        YY=abs(ifftshift(ifft2(fftshift(F))));
        if (showims==1)
            figure;
            imagesc(abs(YY))
            axis image, colormap(gray), axis off
        end
    end
end





