% generate matrix for Gaussian image smoothing
% only generates one part for real or imaginary
% does not assume wrap around

function [S] = getSmooth(Ny,fwhm)

Nx=Ny;
%Compute the variance of the Gaussian kernel
sigmaSq = ((fwhm/2)^2)/(2*log(2));

% Create the smoothing mask
SmMask = spalloc(Ny,Nx,Ny*Nx);
for i=1:Ny
    rowVal = -Ny/2-1+i;
    for j=1:Nx
        colVal = -Nx/2-1+j;
        radius = sqrt(rowVal^2 + colVal^2);
        if (radius/sqrt(sigmaSq)<=5)
            SmMask(i,j) = (1/(2*pi*sigmaSq))*exp(-radius^2/(2*sigmaSq));
        end
    end
end
SmMask = SmMask ./ sum(sum(SmMask));
% divide by sum of sq to preserve variance
% SmMask = SmMask ./ sqrt(sum(sum(SmMask.^2)));

SmRow=circshift(reshape(SmMask,1,Nx*Ny),[0,-((Ny/2+1)*Nx-Nx/2)]);
NonZero=length(find(SmMask~=0));
clear SmMask

S=spalloc(Ny*Nx,Ny*Nx,Ny*Nx*NonZero);

for j=1:Ny*Nx/2
    S(j,:)=circshift(SmRow,[0,j-1]);                 % top half
    S(Ny*Nx/2+j,:)=circshift(SmRow,[0,Ny*Nx/2+j-1]); % bottom half
end
%S(Ny*Nx/2+1,:)=SmRow;
clear SmRow

% to get rid of wrap around weights
S(1:Ny*Nx/4,3*Ny*Nx/4+1:Ny*Nx)=spalloc(Ny*Nx/4,Ny*Nx/4,0);
S(3*Ny*Nx/4+1:Ny*Nx,1:Ny*Nx/4)=spalloc(Ny*Nx/4,Ny*Nx/4,0);

