
clear all
close all

% can do any dimension smaller illustrative examples by changing 
% Nky, Ny values in lines 34-40. See commented out lines.

showims=0;  % whether to display intermediate images
savemats=0; % whether to save operators, mean, var, cov, and corr
fullcorr=0; % whether to calculate the full correlation matrix
domagsq=0;  % whether to calculate magnitude square correlations

corTH=.001; % Threshold value for correlation images
maxMag=7.5;  % maximum intensity value of M and +/- for R-I
maximumO=1.1e-4;

% Processing flags: 0 for no, 1 for yes
disp('Setting Processing Flags')
pause(.1)

kc=30; w=15;  % Tukey k-space apodization
fwhm=2;       % Gaussian Voxel Smoothing 

ift=1; % Keep this at 1 to reconstruct images

% in loops to run all 8 combinations. Can set to single values.
for zfill=[0,1]; %i.e. zfill=1;
    for kapod=[0,1]; % ie kapod=1;
        for smooth=[0,1]; %i.e. smooth=1;
           
            disp(['Operators_','zfill_',num2str(zfill),'_kapod_',num2str(kapod),'_ift_',num2str(ift),'_smooth_',num2str(smooth)])
            
            % k-space processing operations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            % these can be set smaller for illustration by changing commenting
            if (zfill==0)
                NKy=96; NKx=NKy; Ny=NKy;  Nx=NKx;
                %NKy=32; NKx=NKy; Ny=NKy;  Nx=NKx; % for example
            elseif (zfill==1)
                NKy=64; NKx=NKy; Ny=96;  Nx=Ny;
                %NKy=24; NKx=NKy; Ny=32;  Nx=Ny;    % for example
            end
            
            % Set operations to identity for subsequent pre-multiplications
            O=speye(NKy*NKx);
            
            
            
            if (zfill==1)
                disp('Generating Zero Fill Matrix')
                pause(.1)
                [Z] = getZ(NKy,Ny);
                if (savemats==1)
                    save(['Z_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Z')
                end
                
                if (showims==1)
                    figure;
                    imagesc(Z,[-1 1]);
                    axis image,colormap(gray), axis off
                    %print(gcf,'-dtiffn','-r300',['Zop_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                end
                
                O=Z*O;
                clear Z
            end
            
            if kapod==1;
                disp('Generating k-space Apodization Matrix')
                pause(.1)
                
                [A]=getApod(Ny,kc,w);
                
                if (savemats==1)
                    save(['A_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'A')
                end
                
                O=A*O;
                clear A
            end
            
            % Reconstruction Processing Operations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            if (ift==1)
                disp('Generate Omega IFT Matrix')
                pause(.1)
                
                % Omega=[OmegaR,-OmegaI;OmegaI,OmegaR];
                [OmegaR,OmegaI] = getOmega(Nx);
                
                if (savemats==1)
                    save(['OmegaR_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'OmegaR')
                    save(['OmegaI_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'OmegaI')
                end
                
                if (showims==1)
                    figure;
                    imagesc([OmegaR,-OmegaI;OmegaI,OmegaR])
                    axis image,colormap(gray), axis off
                    %print(gcf,'-dtiffn','-r300',['Omegaop_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                end
                
                O11 =  OmegaR*O;
                O22 =  OmegaR*O;
                clear  OmegaR
                O12 = -OmegaI*O;
                O21 =  OmegaI*O;
                clear OmegaI O
            end
            
            % Image Space Operations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            if (smooth==1)
                disp('Generate Image Smoothing Matrix')
                pause(.1)
                [S] = getSmooth(Ny,fwhm);
                if (savemats==1)
                    save(['S_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'S')
                end
                
                if (showims==1)
                    figure;
                    imagesc(S,[-max(max(S)),max(max(S))])
                    axis image,colormap(gray), axis off
                    %print(gcf,'-dtiffn','-r300',['Sop_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                end
                
                O11 =  S*O11;
                O12 =  S*O12;
                O21 =  S*O21;
                O22 =  S*O22;
                
                clear S
            end
            save(['O11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'O11')
            save(['O12_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'O12')
            save(['O21_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'O21')
            save(['O22_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'O22')
            
            maxO=max([max(max(abs(O11))),max(max(abs(O12))),max(max(abs(O21))),max(max(abs(O22)))]);
            save(['maxO_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'maxO')
            
            load myposnegmapblk.txt
            figure;
            imagesc([O11,O12;O21,O22],[-maximumO,maximumO]);
            axis image,colormap(myposnegmapblk), axis off
            %print(gcf,'-dtiffn','-r300',['O_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            
            % k-space data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            disp('Obtaining k-Space data')
            pause(.1)
            
            [F0] = getF(NKy,showims);
            
            if (showims==1)
                figure;
                imagesc(real(F0))
                axis image, axis off, colormap(gray)
                %print(gcf,'-dtiffn','-r300',['FreqImgR_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                figure;
                imagesc(imag(F0))
                axis image, axis off, colormap(gray)
                %print(gcf,'-dtiffn','-r300',['FreqImgI_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                figure;
                imagesc(abs(F0))
                axis image, axis off, colormap(gray)
                %print(gcf,'-dtiffn','-r300',['FreqImgM_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                figure;
                imagesc(angle(F0),[-pi,pi])
                axis image, axis off, colormap(gray)
                %print(gcf,'-dtiffn','-r300',['FreqImgP_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            end
            
            % create f0 mean k=space vector
            f0=[reshape(real(F0)',NKx*NKy,1);reshape(imag(F0)',NKx*NKy,1)];
            clear F0
            
            if (showims==1)
                figure;
                imagesc(repmat(f0,[1,16]));
                axis image,colormap(gray), axis off
                %print(gcf,'-dtiffn','-r300',['kspacevec_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                
            end
            
            % Compute Image Mean %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            disp('Computing Mean of Voxels')
            pause(.1)
            muR=[O11,O12]*f0; muI=[O21,O22]*f0;
            clear f0
            muvec=[muR;muI];
            if (savemats==1)||(domagsq==1)
                save(['muvec_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'muvec')
            end
            clear muR muI
            
            if (showims==1)
                figure;
                imagesc(repmat(muvec,[1,16]),[-1,1]);
                axis image,colormap(gray), axis off
                %print(gcf,'-dtiffn','-r300',['imagevec_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            end
            
            Mu=complex(reshape(muvec(1:Ny*Nx,1),Ny,Nx)',reshape(muvec(Ny*Nx+1:2*Ny*Nx,1),Ny,Nx)');
            clear muvec
            save(['Mu_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Mu')
        
            figure;
            imagesc(real(Mu),[-maxMag,maxMag])
            axis image; colormap gray; axis off
            %print(gcf,'-dtiffn','-r300',['ImageR_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            
            figure;
            imagesc(imag(Mu),[-maxMag,maxMag])
            axis image; colormap gray; axis off
            %print(gcf,'-dtiffn','-r300',['ImageI_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            
            figure;
            imagesc(abs(Mu),[0,maxMag])
            axis image; colormap gray; axis off
            %print(gcf,'-dtiffn','-r300',['ImageM_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            figure;
            imagesc(angle(Mu), [-pi pi])
            axis image; colormap gray; axis off
            %print(gcf,'-dtiffn','-r300',['ImageP_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            % clear Mu % needed later for correlation underlay
            
            % Compute Image Covariance %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            disp('Computing Covarince Between Voxels')
            pause(.1)
            
            % Sigma=O*O';, Sigma=[O11,O12;O21,O22]*[O11,O12;O21,O22]';
            % perform the multiplication in parts to save memory
            
            row = floor(Ny/2)+1; col = floor(Nx/2)+1; % center vox
            rownum = (row-1)*Nx+col;
            
            if (fullcorr==0) % streamlined version doesnt calculate entire corr mat
                Sigma11=O11*O11';
                Sigma11=Sigma11+O12*O12';
                if (savemats==1)||(domagsq==1)
                    save(['Sigma11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma11')
                end
                VariancesR=diag(Sigma11);
                
                corrSigma_real=sparse(1,(row-1)*Ny+col,1/sqrt(VariancesR((row-1)*Ny+col,1)),1,Nx*Ny)...
                    *Sigma11*sparse((1:Ny*Nx)',(1:Ny*Nx)',1./sqrt(VariancesR),Ny*Nx,Ny*Nx);
                clear Sigma11
                corrSigma_real = reshape(corrSigma_real,Nx,Ny)';
                
                Sigma12=O12*O22';
                Sigma12=Sigma12+O11*O21';
                clear O11 O12
                if (savemats==1)||(domagsq==1)
                    save(['Sigma12_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma12')
                end
                
                Sigma22=O22*O22';
                Sigma22=Sigma22+O21*O21';
                clear O22 O21
                if (savemats==1)||(domagsq==1)
                    save(['Sigma22_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma22')
                end
                VariancesI=diag(Sigma22);
                
                corrSigma_imag=sparse(1,(row-1)*Ny+col,1/sqrt(VariancesI((row-1)*Ny+col,1)),1,Nx*Ny)...
                    *Sigma22*sparse((1:Ny*Nx)',(1:Ny*Nx)',1./sqrt(VariancesI),Ny*Nx,Ny*Nx);
                clear Sigma22
                corrSigma_imag = reshape(corrSigma_imag,Nx,Ny)';
                
                corrSigma_reim=sparse(1,(row-1)*Ny+col,1/sqrt(VariancesR((row-1)*Ny+col,1)),1,Nx*Ny)...
                    *Sigma12*sparse((1:Ny*Nx)',(1:Ny*Nx)',1./sqrt(VariancesI),Ny*Nx,Ny*Nx);
                clear Sigma12
                corrSigma_reim = reshape(corrSigma_reim,Nx,Ny)';
                
                VarImgR=reshape(VariancesR,Nx,Ny)';
                VarImgI=reshape(VariancesI,Nx,Ny)';
                clear VariancesR VariancesI
            else % calculates entire correlation matrix
                Sigma22=O22*O22'+O21*O21';
                if (savemats==1)||(domagsq==1)
                    save(['Sigma22_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma22')
                end
                Sigma12=O12*O22'+O11*O21';
                clear O22 O21
                if (savemats==1)||(domagsq==1)
                    save(['Sigma12_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma12')
                end
                Sigma11=O11*O11'+O12*O12';
                clear O11 O12
                if (savemats==1)||(domagsq==1)
                    save(['Sigma11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma11')
                end
                
                VariancesR=diag(Sigma11);
                VariancesI=diag(Sigma22);
                
                VarImgR=reshape(VariancesR,Nx,Ny)';
                VarImgI=reshape(VariancesI,Nx,Ny)';
                
                % Compute Image Correlation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                disp('Computing Correlation Between Voxels')
                
                CorrMat11=sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesR),Nx*Ny,Nx*Ny)*Sigma11*sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesR),Nx*Ny,Nx*Ny);
                clear Sigma11
                CorrMat11=round(CorrMat11,6); % get rid of small values
                CorrMat12=sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesR),Nx*Ny,Nx*Ny)*Sigma12*sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesI),Nx*Ny,Nx*Ny);
                clear Sigma12 VariancesR
                CorrMat12=round(CorrMat12,6); % get rid of small values
                CorrMat22=sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesI),Nx*Ny,Nx*Ny)*Sigma22*sparse((1:Nx*Ny)',(1:Nx*Ny)',1./sqrt(VariancesI),Nx*Ny,Nx*Ny);
                clear Sigma22 VariancesI
                CorrMat22=round(CorrMat22,6); % get rid of small values
                
                if (savemats==1)
                    save(['CorrMat11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'CorrMat11')
                    save(['CorrMat12_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'CorrMat12')
                    save(['CorrMat22_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'CorrMat22')
                end
                
                if (showims==1)
                    load myposnegmapblk.txt
                    figure;
                    imagesc(CorrMat11,[-1,1])
                    axis image, colormap(myposnegmapblk), axis off
                    %print(gcf,'-dtiffn','-r300',['CorrMat11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                end
                
                corrSigma_real = transpose(reshape(CorrMat11(rownum,1:Nx*Ny),Ny,Nx));
                corrSigma_reim = transpose(reshape(CorrMat12(rownum,1:Nx*Ny),Ny,Nx));
                corrSigma_imag = transpose(reshape(CorrMat22(rownum,1:Nx*Ny),Ny,Nx));
                
                clear corrSigma11 corrSigma12 corrSigma22
                clear CorrMat11 CorrMat12 CorrMat22
            end
            
            load myposmapblk.txt
            figure;
            imagesc(VarImgR)
            axis image; colormap(myposmapblk); axis off
            %print(gcf,'-dtiffn','-r300',['VarImgR_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            figure;
            imagesc(VarImgI)
            axis image; colormap(myposmapblk); axis off
            %print(gcf,'-dtiffn','-r300',['VarImgI_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            if (savemats==1)
                save(['VarImgR_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'VarImgR')
                save(['VarImgI_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'VarImgI')
            end
            clear VarImgR VarImgI
            
            [newmap] = makeimagecorr(abs(Mu),0,maxMag,corrSigma_real,corTH,1);
            figure;
            makesupimg(newmap,Ny,Nx,1)
            axis off
            %print(gcf,'-dtiffn','-r300',['corrSigma_real_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            [newmap] = makeimagecorr(abs(Mu),0,maxMag,corrSigma_imag,corTH,1);
            figure;
            makesupimg(newmap,Ny,Nx,1)
            axis off
            %print(gcf,'-dtiffn','-r300',['corrSigma_imag_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            [newmap] = makeimagecorr(abs(Mu),0,maxMag,corrSigma_reim,corTH,1);
            figure;
            makesupimg(newmap,Ny,Nx,1)
            axis off
            %print(gcf,'-dtiffn','-r300',['corrSigma_reim_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            
            save(['corrSigma_real_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'corrSigma_real')
            save(['corrSigma_imag_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'corrSigma_imag')
            save(['corrSigma_reim_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'corrSigma_reim')
            clear save corrSigma_real corrSigma_imag corrSigma_reim
            
            % Calculate magnitude-squared covariance and correlation %%%%%%%%%%%%%%%%%%-------------------------------------------------------------------------
            if (domagsq==1)
                disp('Computing Magnitude Squared Covariance and Correlation')
                pause(0.1)
                
                load(['muvec_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'muvec')
                load(['Sigma11_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma11')
                load(['Sigma12_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma12')
                load(['Sigma22_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Sigma22')
                
                if (fullcorr==1)
                    Lambda = zeros(Nx*Ny,Nx*Nx);
                    for i = 1:Nx*Ny
                        if mod(i,2*Ny)==0 % to monitor progress, counts off two rows
                            disp(['Voxel ',num2str(i),' of ',num2str(Nx*Ny)])
                        end
                        for j = i:Ny*Ny % upper triangular loop
                            mui = [muvec(i,1); muvec(Nx*Ny+i,1)];
                            muj = [muvec(j,1); muvec(Nx*Ny+j,1)];
                            
                            cov_mat =...
                                [Sigma11(i,i), Sigma12(i,i), Sigma11(i,j), Sigma12(i,j);...
                                Sigma12(i,i),  Sigma22(i,i), Sigma12(j,i), Sigma22(i,j);...
                                Sigma11(i,j),  Sigma12(j,i), Sigma11(j,j), Sigma12(j,j);...
                                Sigma12(i,j),  Sigma22(i,j), Sigma12(j,j), Sigma22(j,j)];
                            
                            Lambda(i,i) = 2*trace((cov_mat(1:2,1:2))'*(cov_mat(1:2,1:2)))+4*mui'*(cov_mat(1:2,1:2))*mui;
                            Lambda(j,j) = 2*trace((cov_mat(3:4,3:4))'*(cov_mat(3:4,3:4)))+4*muj'*(cov_mat(3:4,3:4))*muj;
                            Lambda(i,j) = 2*trace((cov_mat(1:2,3:4))'*(cov_mat(1:2,3:4)))+4*mui'*(cov_mat(1:2,3:4))*muj;
                            Lambda(j,i) = Lambda(i,j);
                        end
                    end
                    clear Sigma11 Sigma12 Sigma22 mu mui muj cov_mat
                    
                    if (savemats==1)
                        save(['Lambda_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Lambda')
                    end
                else
                    % Calculates diagonal (variances) and row and col for rownum
                    Lambda = spalloc(Nx*Ny,Nx*Ny,3*Nx*Ny-2);
                    for i = 1:Nx*Ny
                        for j = rownum % voxel of interest
                            mui = [muvec(i,1); muvec(Nx*Ny+i,1)];
                            muj = [muvec(j,1); muvec(Nx*Ny+j,1)];
                            cov_mat =...
                                [Sigma11(i,i), Sigma12(i,i), Sigma11(i,j), Sigma12(i,j);...
                                Sigma12(i,i),  Sigma22(i,i), Sigma12(j,i), Sigma22(i,j);...
                                Sigma11(i,j),  Sigma12(j,i), Sigma11(j,j), Sigma12(j,j);...
                                Sigma12(i,j),  Sigma22(i,j), Sigma12(j,j), Sigma22(j,j)];
                            Lambda(i,i) = 2*trace((cov_mat(1:2,1:2))'*(cov_mat(1:2,1:2)))+4*mui'*(cov_mat(1:2,1:2))*mui;
                            Lambda(j,j) = 2*trace((cov_mat(3:4,3:4))'*(cov_mat(3:4,3:4)))+4*muj'*(cov_mat(3:4,3:4))*muj;
                            Lambda(i,j) = 2*trace((cov_mat(1:2,3:4))'*(cov_mat(1:2,3:4)))+4*mui'*(cov_mat(1:2,3:4))*muj;
                            Lambda(j,i) = Lambda(i,j);
                        end
                    end
                    clear Sigma11 Sigma12 Sigma22 mu mui muj cov_mat
                    if (savemats==1)
                        save(['Lambda_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'Lambda')
                    end
                end
                load myposnegmapblk.txt
                maxLambda=max(max(abs(Lambda)));
                figure;
                imagesc(Lambda,[-maxLambda,maxLambda]);
                axis image,colormap(myposnegmapblk), axis off
                
                
                % mag-sq variances
                VarImgM2=reshape(diag(Lambda),Ny,Nx)';
                if (savemats==1)
                    save(['VarImgM2_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'VarImgM2')
                end
                
                load myposmapblk.txt
                figure;
                imagesc(VarImgM2);
                axis image,colormap(myposmapblk), axis off
                %print(gcf,'-dtiffn','-r300',['VarMagSq_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
                
                corrLambda_MagSq = diag(1./sqrt(diag(Lambda)))*Lambda*diag(1./sqrt(diag(Lambda)));
                clear Lambda
                
                % correlation for voxel of choice
                corrLambda_MagSqIm = transpose(reshape(corrLambda_MagSq(rownum,1:Nx*Ny),Nx,Ny));
                if (savemats==1)
                    save(['corrLambda_MagSqIm_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)'],'corrLambda_MagSqIm')
                end
                save corrLambda_MagSq corrLambda_MagSq
                
                figure;
                [newmap] = makeimagecorr(abs(Mu),0,maxMag,corrLambda_MagSqIm,corTH,1);
                makesupimg(newmap,Ny,Nx,1)
                axis off
                %print(gcf,'-dtiffn','-r300',['CorrVoxMagSq_NKy_',num2str(NKy),'_ZFeq',num2str(zfill),'Ny_',num2str(Ny),'APeq_',num2str(kapod),'IFTeq_',num2str(ift),'SMeq_',num2str(smooth)])
            end
            
        end
    end
end




